@@ -87,7 +87,8 @@ class ImageNode(Node):
 
         if getMetaData:
             self.get_metadata_from_exif_data()
-            self.get_metadata_from_resource()
+            if getResource or self._resource is not None:
+                self.get_metadata_from_resource()
 
 #---------------------PROPERTIES----------------------------
 
@@ -180,8 +181,8 @@ class ImageNode(Node):
         Returns:
             np.ndarray or None
         """
-        if self.resource is not None :
-            pass
+        if self._resource is not None :
+            return self._resource
         elif self.get_path():
             self._resource   = cv2.imread(self.path)
         return self._resource  
