@@ -173,16 +173,18 @@ class PointCloudNode (GeometryNode):
         if extension not in ut.PCD_EXTENSION:
             raise ValueError('Invalid extension')
 
+        filename=ut.validate_string(self.name)
+
         # check if already exists
-        if directory and os.path.exists(os.path.join(directory,self.get_name() + extension)):
-            self.path=os.path.join(directory,self.get_name() + extension)
+        if directory and os.path.exists(os.path.join(directory,filename + extension)):
+            self.path=os.path.join(directory,filename + extension)
             return True
-        elif not directory and self.get_path() and os.path.exists(self.path) and extension in ut.MESH_EXTENSION:
+        elif not directory and self.subject and os.path.exists(self.path) and extension in ut.MESH_EXTENSION:
             return True        
                    
         #get path        
         if directory:
-            self.path=os.path.join(directory,self.get_name() + extension)
+            self.path=os.path.join(directory,filename + extension)
         else:
             if self.get_path():
                 directory = ut.get_folder(self.path)
@@ -190,10 +192,10 @@ class PointCloudNode (GeometryNode):
             elif(self.graphPath): 
                 dir=ut.get_folder(self.graphPath)
                 directory=os.path.join(dir,'PCD')   
-                self.path=os.path.join(dir,self.get_name() + extension)
+                self.path=os.path.join(dir,filename + extension)
             else:
                 directory=os.path.join(os.getcwd(),'PCD')
-                self.path=os.path.join(dir,self.get_name() + extension)
+                self.path=os.path.join(dir,filename + extension)
         # create directory if not present
         if not os.path.exists(directory):                        
             os.mkdir(directory) 
