@@ -531,8 +531,8 @@ class SessionNode(GeometryNode):
         Returns:
             o3d.geometry.TriangleMesh or None
         """
-        if self.resource is not None and len(self.resource.triangles)>=2:
-            pass
+        if self._resource is not None and len(self._resource.triangles)>=2:
+            return self._resource
         elif self.get_path():
             self._resource   =  o3d.io.read_triangle_mesh(self.path)
         elif self.linkedNodes:
@@ -544,8 +544,8 @@ class SessionNode(GeometryNode):
                         points.extend(box.get_box_points()) 
             pcd= o3d.geometry.PointCloud()
             pcd.points=points
-            self.resource=pcd.compute_convex_hull()   
-        return self.resource  
+            self._resource=pcd.compute_convex_hull()   
+        return self._resource  
 
     
     def get_metadata_from_resource(self) -> bool:
