@@ -419,6 +419,7 @@ class TestGeometryutils(unittest.TestCase):
 
     def test_e57_get_colors(self):
         e57=pye57.E57(str(self.e57Path1)) 
+        gt.e57_update_point_field(e57)
         raw_data = e57.read_scan_raw(0)  
         header = e57.get_header(0)
         self.assertEqual(len(raw_data["cartesianX"]) , header.point_count)
@@ -528,7 +529,7 @@ class TestGeometryutils(unittest.TestCase):
         self.assertEqual(len(percentages), len(sources))
         self.assertLess(percentages[0],0.005)
         self.assertLess(percentages[1],0.001)
-        self.assertLess(percentages[2],0.4)
+        self.assertLess(percentages[2],0.5)
         self.assertLess(percentages[3],0.001)
 
     def test_show_geometries(self):
@@ -550,14 +551,14 @@ class TestGeometryutils(unittest.TestCase):
         meshes=[self.slabMesh,self.wallMesh,self.columnMesh,self.beamMesh]
         cutters=[gt.mesh_to_trimesh(mesh) for mesh in meshes]
 
-        innerCrop=gt.crop_geometry_by_convex_hull(source=sourceMesh, cutters=cutters, inside = True )
+        innerCrop=gt.crop_mesh_by_convex_hull(source=sourceMesh, cutters=cutters, inside = True )
         self.assertEqual(len(innerCrop),4)
         self.assertGreater(len(innerCrop[0].vertices),12000)
         self.assertGreater(len(innerCrop[1].vertices),800)
         self.assertGreater(len(innerCrop[2].vertices),1000)
         self.assertGreater(len(innerCrop[3].vertices),1000)
 
-        outerCrop=gt.crop_geometry_by_convex_hull(source=sourceMesh, cutters=cutters[0], inside = False ) 
+        outerCrop=gt.crop_mesh_by_convex_hull(source=sourceMesh, cutters=cutters[0], inside = False ) 
         self.assertGreater(len(outerCrop[0].vertices),255000)         
         
 #    def test_crop_geometry_by_raycasting(self):
